**********************
The sherpa.plot module
**********************

.. currentmodule:: sherpa.plot

.. automodule:: sherpa.plot

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Confidence1D
      IntervalProjection
      IntervalUncertainty
      Confidence2D
      RegionProjection
      RegionUncertainty
      Contour
      DataContour
      PSFContour
      FitContour
      ModelContour
      RatioContour
      ResidContour
      SourceContour
      Histogram
      Plot
      DataPlot
      PSFPlot
      FitPlot
      ModelPlot
      ChisqrPlot
      ComponentModelPlot
      DelchiPlot
      RatioPlot
      ResidPlot
      SourcePlot
      ComponentSourcePlot
      ModelHistogramPlot
      SourceHistogramPlot
      ComponentModelHistogramPlot
      ComponentSourceHistogramPlot
      SplitPlot
      JointPlot
      Point

Class Inheritance Diagram
=========================

.. inheritance-diagram::   Confidence1D IntervalProjection IntervalUncertainty Confidence2D RegionProjection RegionUncertainty Contour DataContour PSFContour FitContour ModelContour RatioContour ResidContour SourceContour Histogram Plot DataPlot PSFPlot FitPlot ModelPlot ChisqrPlot ComponentModelPlot DelchiPlot RatioPlot ResidPlot SourcePlot ComponentSourcePlot ModelHistogramPlot SourceHistogramPlot ComponentModelHistogramPlot ComponentSourceHistogramPlot SplitPlot JointPlot Point
   :parts: 1
